@@ -3,7 +3,10 @@ from enum import unique
 from oldaplib.src.dtypes.namespaceiri import NamespaceIRI
 from oldaplib.src.enums.attributeclass import AttributeClass
 from oldaplib.src.helpers.langstring import LangString
+from oldaplib.src.helpers.observable_dict import ObservableDict
 from oldaplib.src.xsd.iri import Iri
+from oldaplib.src.xsd.xsd_anyuri import Xsd_anyURI
+from oldaplib.src.xsd.xsd_boolean import Xsd_boolean
 from oldaplib.src.xsd.xsd_date import Xsd_date
 from oldaplib.src.xsd.xsd_ncname import Xsd_NCName
 
