@@ -38,7 +38,7 @@ class RdfModifyRes:
     def __rdf_modify_property(cls, *,
                               shacl: bool,
                               action: Action,
-                              owlclass_iri: Iri,
+                              owlclass_iri: Xsd_QName,
                               graph: Xsd_QName,
                               ele: RdfModifyItem,
                               last_modified: Xsd_dateTime,
@@ -78,7 +78,7 @@ class RdfModifyRes:
     def shacl(cls, *,
               action: Action,
               graph: Xsd_NCName,
-              owlclass_iri: Iri,
+              owlclass_iri: Xsd_QName,
               ele: RdfModifyItem,
               last_modified: Xsd_dateTime,
               indent: int = 0, indent_inc: int = 4):
@@ -91,7 +91,7 @@ class RdfModifyRes:
     def onto(cls, *,
              action: Action,
              graph: Xsd_NCName,
-             owlclass_iri: Iri,
+             owlclass_iri: Xsd_QName,
              ele: RdfModifyItem,
              last_modified: Xsd_dateTime,
              indent: int = 0, indent_inc: int = 4):
@@ -107,8 +107,8 @@ class RdfModifyProp:
     def __rdf_modify_property(cls, *,
                               shacl: bool,
                               action: Action,
-                              owlclass_iri: Iri | None = None,
-                              pclass_iri: Iri,
+                              owlclass_iri: Xsd_QName | None = None,
+                              pclass_iri: Xsd_QName,
                               graph: Xsd_QName,
                               ele: RdfModifyItem,
                               last_modified: Xsd_dateTime,
@@ -150,8 +150,8 @@ class RdfModifyProp:
     def shacl(cls, *,
               action: Action,
               graph: Xsd_NCName,
-              owlclass_iri: Iri | None = None,
-              pclass_iri: Iri,
+              owlclass_iri: Xsd_QName | None = None,
+              pclass_iri: Xsd_QName,
               ele: RdfModifyItem,
               last_modified: Xsd_dateTime,
               indent: int = 0, indent_inc: int = 4) -> str:
@@ -164,8 +164,8 @@ class RdfModifyProp:
     def onto(cls, *,
              action: Action,
              graph: Xsd_NCName,
-             owlclass_iri: Iri | None = None,
-             pclass_iri: Iri,
+             owlclass_iri: Xsd_QName | None = None,
+             pclass_iri: Xsd_QName,
              ele: RdfModifyItem,
              last_modified: Xsd_dateTime,
              indent: int = 0, indent_inc: int = 4) -> str:
@@ -177,8 +177,8 @@ class RdfModifyProp:
     @classmethod
     def replace_rdfset(cls, *,
                        action: Action,
-                       owlclass_iri: Iri | None = None,
-                       pclass_iri: Iri,
+                       owlclass_iri: Xsd_QName | None = None,
+                       pclass_iri: Xsd_QName,
                        graph: Xsd_QName,
                        ele: RdfModifyItem,
                        last_modified: Xsd_dateTime,
