@@ -64,7 +64,7 @@ It identifies a hierarchical list, but is itself not a list item.
 A list item object is a `skos:Concept` with the following properties:
 
 - `skos:inScheme`: points to the list object
-- `skos:broaderTransitive`: points to the parent node if there is one
+- `skos:broader`: points to the parent node if there is one
 - `skos:prefLabel`: A description of the list item. Must be a LangString.
 - `skos:definition`: A LangString describing the list item more verbose.
 - `oldap:nextNode`: Pointer to the next list item (will be automatically managed by OLDAP)
@@ -370,7 +370,7 @@ class OldapList(Model):
                     ?node skos:definition ?definition .
                 }}
                 OPTIONAL {{
-                    ?node skos:broaderTransitive ?parent .
+                    ?node skos:broader ?parent .
                 }}
             }}
         }}
@@ -383,7 +383,7 @@ class OldapList(Model):
         last_nodeiri = None
         for r in res:
             nodeiri = r['node']
-            if last_nodeiri != nodeiri:
+            if last_nodeiri is None or last_nodeiri != nodeiri:
                 prefix, id = str(nodeiri).split(':')
                 ln = OldapListNode(con=self._con,
                                    **self.info,
@@ -501,10 +501,10 @@ class OldapList(Model):
                         definition = LangString()
                     definition.add(r['val'])
         if prefLabel:
-            prefLabel.changeset_clear()
+            prefLabel.clear_changeset()
             prefLabel.set_notifier(cls.notifier, Xsd_QName(OldapListAttr.PREF_LABEL.value))
         if definition:
-            definition.changeset_clear()
+            definition.clear_changeset()
             definition.set_notifier(cls.notifier, Xsd_QName(OldapListAttr.DEFINITION.value))
 
         instance = cls(con=con,
