@@ -16,7 +16,8 @@ from oldaplib.src.xsd.xsd_qname import Xsd_QName
 from oldaplib.src.xsd.xsd_ncname import Xsd_NCName
 from oldaplib.src.xsd.xsd_date import Xsd_date
 from oldaplib.src.helpers.langstring import LangString
-from oldaplib.src.helpers.oldaperror import OldapErrorNotFound, OldapErrorInconsistency, OldapErrorNoPermission
+from oldaplib.src.helpers.oldaperror import OldapErrorNotFound, OldapErrorInconsistency, OldapErrorNoPermission, \
+    OldapErrorAlreadyExists
 from oldaplib.src.project import Project, ProjectSearchResult
 from oldaplib.src.helpers.serializer import serializer
 
@@ -90,6 +91,9 @@ class Testproject(unittest.TestCase):
         self.assertEqual(project.projectEnd, project2.projectEnd)
 
 
+    def test_project_read_with_uses_ontologies(self):
+        project = Project.read(con=self._connection, projectIri_SName="hyha", ignore_cache=True)
+
     # @unittest.skip('Work in progress')
     def test_project_read(self):
         project = Project.read(con=self._connection, projectIri_SName=Iri("oldap:SystemProject"), ignore_cache=True)
@@ -124,7 +128,7 @@ class Testproject(unittest.TestCase):
     # @unittest.skip('Work in progress')
     def test_project_search(self):
         projects = Project.search(con=self._connection, label="HyperHamlet")
-        self.assertEqual({ProjectSearchResult(Iri("oldap:HyperHamlet"), Xsd_NCName("hyha"))}, set(projects))
+        self.assertEqual({ProjectSearchResult(Xsd_QName("oldap:HyperHamlet"), Xsd_NCName("hyha"))}, set(projects))
 
     # @unittest.skip('Work in progress')
     def test_project_search_fail(self):
@@ -133,11 +137,10 @@ class Testproject(unittest.TestCase):
 
     def test_project_search_all(self):
         projects = Project.search(con=self._connection)
-        print(projects)
-        self.assertEqual({ProjectSearchResult(Iri("oldap:SystemProject"), Xsd_NCName("oldap")),
-                          ProjectSearchResult(Iri("oldap:SharedProject"), Xsd_NCName("shared")),
-                          ProjectSearchResult(Iri("oldap:HyperHamlet"), Xsd_NCName("hyha")),
-                          ProjectSearchResult(Iri("http://www.salsah.org/version/2.0/SwissBritNet"), Xsd_NCName("britnet"))}, set(projects))
+        self.assertTrue(set(projects) >= {ProjectSearchResult(Xsd_QName("oldap:SystemProject"), Xsd_NCName("oldap")),
+                          ProjectSearchResult(Xsd_QName("oldap:SharedProject"), Xsd_NCName("shared")),
+                          ProjectSearchResult(Xsd_QName("oldap:HyperHamlet"), Xsd_NCName("hyha")),
+                          ProjectSearchResult(Iri("http://www.salsah.org/version/2.0/SwissBritNet"), Xsd_NCName("britnet"))})
 
     def test_project_create_simplest(self):
         project = Project(con=self._connection,
@@ -261,6 +264,33 @@ class Testproject(unittest.TestCase):
         project = Project.read(con=self._connection, projectIri_SName="unittest6", ignore_cache=True)
         project.delete()
 
+    def test_duplicate_project_create(self):
+        project1 = Project(con=self._connection,
+                           projectShortName="unittestXX",
+                           namespaceIri=NamespaceIRI("http://unitest.org/project/unittestXX#"),
+                           label=LangString(["unittestXX@en", "unittestXX@de"]))
+        project1.create()
+        project2 = Project(con=self._connection,
+                           projectShortName="unittestXX",
+                           namespaceIri=NamespaceIRI("http://unitest.org/project/unittestYY#"),
+                           label=LangString(["unittestXX@en", "unittestXX@de"]))
+        with self.assertRaises(OldapErrorAlreadyExists) as ex:
+            project2.create()
+
+        project3 = Project(con=self._connection,
+                           projectShortName="unittestYY",
+                           namespaceIri=NamespaceIRI("http://unitest.org/project/unittestXX#"),
+                           label=LangString(["unittestXX@en", "unittestXX@de"]))
+        with self.assertRaises(OldapErrorAlreadyExists) as ex:
+            project3.create()
+
+        project4 = Project(con=self._connection,
+                           projectIri=project1.projectIri,
+                           projectShortName="unittestZZ",
+                           namespaceIri=NamespaceIRI("http://unitest.org/project/unittestZZ#"),
+                           label=LangString(["unittestZZ@en", "unittestZZ@de"]))
+        with self.assertRaises(OldapErrorAlreadyExists) as ex:
+            project4.create()
 
     def test_project_create_without_label_comment(self):
         project = Project(con=self._connection,
@@ -276,6 +306,7 @@ class Testproject(unittest.TestCase):
         project = Project.read(con=self._connection, projectIri_SName="emptyfieldsXX", ignore_cache=True)
         project.delete()
 
+
     def test_project_create_empty_fields(self):
         project = Project(con=self._connection,
                           projectShortName="emptyfields1",
